@@ -2,6 +2,7 @@ use crate::api::{PullRequest, ReceivedMessage};
 use crate::client::Client;
 use crate::message::Message;
 use anyhow::Result;
+use log::debug;
 use std::collections::VecDeque;
 
 pub struct Subscription {
@@ -43,12 +44,15 @@ impl Subscription {
                         timestamp.nanos as u32,
                     ),
                 };
+                debug!("got message and break");
                 break Some(message);
             } else {
                 if let Ok(messages) = self.pull(50).await {
                     if messages.is_empty() {
+                        debug!("got empty message and break");
                         break None;
                     }
+                    debug!("pulled new message(s) and extend to buffer");
                     self.buffer.extend(messages)
                 }
             }
